@@ -33,68 +33,26 @@ sub get_runlevel_roles
 
   %dist_map =
     (
-     "redhat-5.2"     => "redhat-5.2",
-     "redhat-6.0"     => "redhat-5.2",
-     "redhat-6.1"     => "redhat-5.2",
-     "redhat-6.2"     => "redhat-5.2",
-     "redhat-7.0"     => "redhat-5.2",
-     "redhat-7.1"     => "redhat-5.2",
-     "redhat-7.2"     => "redhat-5.2",
-     "redhat-7.3"     => "redhat-5.2",
-     "redhat-8.0"     => "redhat-5.2",
-     "redhat-9"       => "redhat-5.2",
-     "openna-1.0"     => "redhat-5.2",
-     
-     "mandrake-7.1"   => "redhat-5.2",
-     "mandrake-7.2"   => "redhat-5.2",
-     "mandrake-9.0"   => "redhat-5.2",
-     "mandrake-9.1"   => "redhat-5.2",
-     "mandrake-9.2"   => "redhat-5.2",
-     "mandrake-10.0"  => "redhat-5.2",
-     "mandrake-10.1"  => "redhat-5.2",
-     
-     "blackpanther-4.0" => "redhat-5.2",
-
-     "conectiva-9"    => "redhat-5.2",
-     "conectiva-10"   => "redhat-5.2",
-     
-     "debian-2.2"     => "debian-2.2",
-     "debian-3.0"     => "debian-2.2",
-     "debian-sarge"   => "debian-2.2",
-     "ubuntu-5.04"    => "debian-2.2",     
-          
-     "suse-7.0"       => "redhat-5.2",
-     "suse-9.0"       => "redhat-5.2",
-     "suse-9.1"       => "redhat-5.2",
-     
-     "turbolinux-7.0" => "redhat-5.2",
-     "pld-1.0"        => "redhat-5.2",
-     "pld-1.1"        => "redhat-5.2",
-     "pld-1.99"       => "redhat-5.2",
-     "fedora-1"       => "redhat-5.2",
-     "fedora-2"       => "redhat-5.2",
-     "fedora-3"       => "redhat-5.2",
-
-     "rpath"          => "redhat-5.2",
-
-     "vine-3.0"       => "redhat-5.2",
-     "vine-3.1"       => "redhat-5.2",
-
+     "redhat-6.2"       => "redhat-6.2",
+     "redhat-7.0"       => "redhat-6.2",
+     "redhat-7.1"       => "redhat-6.2",
+     "redhat-7.2"       => "redhat-6.2",
+     "redhat-7.3"       => "redhat-6.2",
+     "redhat-8.0"       => "redhat-6.2",
+     "mandrake-9.0"     => "redhat-6.2",
+     "conectiva-9"      => "redhat-6.2",
+     "debian-3.0"       => "debian-3.0",
+     "suse-9.0"         => "redhat-6.2",
+     "pld-1.0"          => "redhat-6.2",
+     "vine-3.0"         => "redhat-6.2",
      "slackware-9.1.0"  => "slackware-9.1.0",
-     "slackware-10.0.0" => "slackware-9.1.0",
-     "slackware-10.1.0" => "slackware-9.1.0",
-
-     "gentoo"         => "gentoo",
-     "vlos-1.2"       => "gentoo",
-
-     "freebsd-5"      => "freebsd-5",
-     "freebsd-6"      => "freebsd-5",
-     "freebsd-7"      => "freebsd-5",
+     "gentoo"           => "gentoo",
+     "freebsd-5"        => "freebsd-5",
     );
 
   %runlevels=
     (
-     "redhat-5.2"      => [["0",         "HALT"      ],
+     "redhat-6.2"      => [["0",         "HALT"      ],
                            ["1",         "RECOVER"   ],
                            ["2",         "NONE"      ],
                            ["3",         "TEXT"      ],
@@ -102,7 +60,7 @@ sub get_runlevel_roles
                            ["5",         "GRAPHICAL" ],
                            ["6",         "REBOOT"    ]],
 
-     "debian-2.2"      => [["0",         "HALT"      ],
+     "debian-3.0"      => [["0",         "HALT"      ],
                            ["1",         "RECOVER"   ],
                            ["2",         "NONE"      ],
                            ["3",         "NONE"      ],
@@ -148,62 +106,20 @@ sub get_sysv_paths
   my %dist_map =
     (
      # gst_dist => [rc.X dirs location, init.d scripts location, relative path location]
-     "redhat-5.2"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "redhat-6.0"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "redhat-6.1"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "redhat-6.2"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "redhat-7.0"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "redhat-7.1"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "redhat-7.2"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "redhat-7.3"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "redhat-8.0"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "redhat-9"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "openna-1.0"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-
-     "mandrake-7.1"  => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "mandrake-7.2"  => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "mandrake-9.0"  => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "mandrake-9.1"  => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "mandrake-9.2"  => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "mandrake-10.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "mandrake-10.1" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "mandrake-10.2" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "mandriva-2006.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "mandriva-2006.1" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-
-     "yoper-2.2" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "blackpanther-4.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-
-     "conectiva-9"   => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "conectiva-10"  => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-
-     "debian-2.2"    => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
-     "debian-3.0"    => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
-     "debian-sarge"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
-     "ubuntu-5.04"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],       
-     "ubuntu-5.10"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
-     "ubuntu-6.04"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
-
-     "suse-7.0"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d", "../"],
-     "suse-9.0"      => ["$gst_prefix/etc/init.d", "$gst_prefix/etc/init.d", "../"],
-     "suse-9.1"      => ["$gst_prefix/etc/init.d", "$gst_prefix/etc/init.d", "../"],
-
-     "turbolinux-7.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-
-     "pld-1.0"       => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "pld-1.1"       => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "pld-1.99"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-
-     "fedora-1"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "fedora-2"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "fedora-3"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "fedora-4"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-
-     "rpath"         => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-
-     "vine-3.0"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "vine-3.1"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-     "ark"           => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "redhat-6.2"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "redhat-7.0"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "redhat-7.1"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "redhat-7.2"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "redhat-7.3"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "redhat-8.0"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "mandrake-9.0"   => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "yoper-2.2"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "conectiva-9"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "debian-3.0"     => ["$gst_prefix/etc",      "$gst_prefix/etc/init.d",      "../init.d"],
+     "suse-9.0"       => ["$gst_prefix/etc/init.d", "$gst_prefix/etc/init.d",    "../"],
+     "pld-1.0"        => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "vine-3.0"       => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+     "ark"            => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
      );
   my $res;
 
@@ -373,7 +289,7 @@ sub set_sysv_services
 sub get_filerc_runlevels_status
 {
   my ($start_service, $stop_service, $priority) = @_;
-  my (@arr, @ret);
+  my (@arr);
 
   # we start with the runlevels in which the service starts
   if ($start_service !~ /-/) {
@@ -383,9 +299,7 @@ sub get_filerc_runlevels_status
 
     foreach $runlevel (@runlevels)
     {
-      push @arr, { "name"     => $runlevel,
-                   "action"   => "start",
-                   "priority" => $priority};
+      push @arr, [ $runlevel, "start", $priority ];
     }
   }
 
@@ -397,21 +311,17 @@ sub get_filerc_runlevels_status
 
     foreach $runlevel (@runlevels)
     {
-      push @arr, { "name"     => $runlevel,
-                   "action"   => "stop",
-                   "priority" => $priority};
+      push @arr, [ $runlevel, "stop", $priority ];
     }
   }
 
-  push @ret, {"runlevel" => \@arr};
-  return \@ret;
+  return \@arr;
 }
 
 sub get_filerc_service_info
 {
   my ($line, %ret) = @_;
-  my %hash;
-  my @runlevels;
+  my (@runlevels, $role);
 
   if ($line =~ /^([0-9][0-9])[\t ]+([0-9\-S,]+)[\t ]+([0-9\-S,]+)[\t ]+\/etc\/init\.d\/(.*)/)
   {
@@ -420,57 +330,55 @@ sub get_filerc_service_info
     $start_service = $3;
     $script = $4;
 
-    return undef if (&Init::ServicesList::is_forbidden ($script));
+    return if (&Init::ServicesList::is_forbidden ($script));
 
-    $hash{"script"} = $script;
+    $runlevels = &get_filerc_runlevels_status ($start_service, $stop_service, $priority);
+    $role = &Init::ServicesList::get_role ($script);
 
-    $hash{"runlevels"} = &get_filerc_runlevels_status ($start_service, $stop_service, $priority);
-    $hash{"role"} = &Init::ServicesList::get_role ($script);
-
-    return (\%hash);
+    return ($script, $role, $runlevels);
   }
 
-  return undef;
+  return;
 }
 
 sub get_filerc_services
 {
 	my ($script);
-  my (%ret);
-	
+  my ($script, @arr, %hash);
+
   open FILE, "$gst_prefix/etc/runlevel.conf" or return undef;
   while ($line = <FILE>)
   {
-    if ($line !~ /^#.*/)
+    next if ($line =~ /^\#.*/);
+
+    my (@info);
+    my ($start_service, $stop_service);
+
+    @info = &get_filerc_service_info ($line);
+    next if (!scalar (@info));
+
+    $script = $info[0];
+
+    if (!$hash{$script})
     {
-      my (%hash);
-      my ($start_service, $stop_service);
-      $hash = &get_filerc_service_info ($line);
-
-      if ($hash ne undef)
+      $hash{$script} = \@info;
+    }
+    else
+    {
+      # We need to mix the runlevels
+      foreach $runlevel (@{$info[2]})
       {
-        $script = $$hash{"script"};
-
-        if ($ret{$script} eq undef)
-        {
-          $ret{$script} = $hash;
-        }
-        else
-        {
-          my (@runlevels);
-
-          # We need to mix the runlevels
-          @runlevels = $$hash{"runlevels"}[0]{"runlevel"};
-          foreach $runlevel (@runlevels)
-          {
-            push @{$ret{$script}{"runlevels"}[0]{"runlevel"}}, $runlevel;
-          }
-        }
+        push @{$hash{$script}[2]}, $runlevel;
       }
     }
   }
 
-  return \%ret;
+  foreach $key (keys %hash)
+  {
+    push @arr, $hash{$key};
+  }
+
+  return \@arr;
 }
 
 # These are the functions for storing the service settings in file-rc
@@ -682,7 +590,7 @@ sub get_gentoo_runlevels
 {
   my($raw_output) = Utils::File::run_backtick("rc-status -l");
   my(@runlevels) = split(/\n/,$raw_output);
-    
+
   return @runlevels;
 }
 
@@ -780,53 +688,47 @@ sub get_gentoo_runlevel_status_by_service
   {
     if (defined $start_runlevels{$runlevel})
     {
-      push @arr, { "name"   => $runlevel,
-                   "action" => "start" };
+      push @arr, [ $runlevel, "start", 0 ];
     }
     else
     {
-      push @arr, { "name"   => $runlevel,
-                   "action" => "stop" };
+      push @arr, [ $runlevel, "stop", 0 ];
     }
   }
 
-  push @ret, { "runlevel" => \@arr };
-  return @ret;
+  return \@arr;
 }
 
 sub get_gentoo_service_info
 {
 	my ($service) = @_;
 	my ($script, @actions, @runlevels);
-	my %hash;
+	my ($role);
 	
 	# We have to check out if the service is in the "forbidden" list
-	return undef if (&Init::ServicesList::is_forbidden ($service));
+	return if (&Init::ServicesList::is_forbidden ($service));
 
-	my($runlevels) = &get_gentoo_runlevel_status_by_service ($service);
+  $runlevels = &get_gentoo_runlevel_status_by_service ($service);
+  $role = &Init::ServicesList::get_role ($service);
 
-	$hash{"script"} = $service;
-	$hash{"runlevels"} = $runlevels unless ($runlevels eq undef);
-  $hash{"role"} = &Init::ServicesList::get_role ($service);
-
-	return \%hash;
+  return ($service, $role, $runlevels);
 }
 
 sub get_gentoo_services
 {
   my ($service);
-  my (%ret);
+  my (@arr);
   my ($service_list) = &get_gentoo_services_list ();
 
   foreach $service (@$service_list)
   {
-    my (%hash);
+    my (@info);
 
-    $hash = &get_gentoo_service_info ($service);
-    $ret{$service} = $hash if ($hash ne undef);
+    @info = &get_gentoo_service_info ($service);
+    push @arr, \@info if scalar (@info);
   }
 
-  return \%ret;
+  return \@arr;
 }
 
 sub set_gentoo_service_status
@@ -1128,6 +1030,10 @@ sub set_suse_services
 # generic functions to get the available services
 sub get_init_type
 {
+  my $gst_dist;
+
+  $gst_dist = $Utils::Backend::tool{"platform"};
+
   if (($gst_dist =~ /debian/) && (Utils::File::exists ("/etc/runlevel.conf")))
   {
     return "file-rc";
